pi.mcar.karpievitch: Estimating the proportion of MCAR values in biological conditions using the method of Karpievitch (2009).
Description
This function allows estimating the proportion of MCAR values in biological conditions using the method of Karpievitch (2009).
Usage
pi.mcar.karpievitch(tab,conditions)
Arguments
tab
A data matrix containing numeric and missing values. Each column of this matrix is assumed to correspond to an experimental sample, and each row to an identified peptide.
conditions
A vector of factors indicating the biological condition to which each column (experimental sample) belongs.
Value
A list composed of:
pi.mcar
The proportion of MCAR values in each biological condition.
prop.na
The proportion of missing values for each peptide in each condition.
moy
The average of observed values for each peptide in each condition.
References
Karpievitch, Y., Stanley, J., Taverner, T., Huang, J., Adkins, J. N., Ansong, C., ... & Smith, R. D. (2009). A statistical framework for protein quantitation in bottom-up MS-based proteomics. Bioinformatics, 25(16), 2028-2034.
# NOT RUN {#Simulating datares.sim=sim.data(nb.pept=2000,nb.miss=600);
#Proportion of MCAR values in each conditionpi.mcar.karpievitch(tab=res.sim$dat.obs,conditions=res.sim$conditions)
# }